%global major_version 19
%define dlname Botan
%define botan_ver 2

%define libname %mklibname botan2_ %{major_version}
%define devname %mklibname botan2 -d

Name:           botan2
Version:        2.19.1
Release:        %mkrel 2
Summary:        Crypto and TLS for C++11
Group:          System/Libraries
License:        BSD
URL:            https://botan.randombit.net/
Source0:        https://botan.randombit.net/releases/%{dlname}-%{version}.tar.xz#!/%{name}-%{version}.tar.xz

# Upstram patch to fix test failure
Patch0:         https://github.com/randombit/botan/pull/2837.patch

BuildRequires:  gcc-c++
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  python3-docutils
BuildRequires:  python3-sphinx
BuildRequires:  graphviz
BuildRequires:  pkgconfig(liblzma)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  boost-devel

Requires:       python3

%description
Botan is a BSD-licensed crypto library written in C++. It provides a
wide variety of basic cryptographic algorithms, X.509 certificates and
CRLs, PKCS \#10 certificate requests, a filter/pipe message processing
system, and a wide variety of other features, all written in portable
C++. The API reference, tutorial, and examples may help impart the
flavor of the library. This is the current stable release branch 2.x
of Botan.

%package        -n %{devname}
Summary:        Development files for %{name}
Group:          Development/Libraries
Requires:       %{name} = %{version}-%{release}
Requires:       %{libname} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}

%description    -n %{devname}
The %{devname} package contains libraries and header files for
developing applications that use %{name}.

%package        -n %{libname}
Summary:        Library files for %{name}
Group:          System/Libraries
Requires:       %{name} >= %{version}-%{release}

%description    -n %{libname}
The %{libname} package contains library files for %{name}.


%package        doc
Summary:        Documentation for %{name}
Group:          Documentation

%description    doc
Documentation for %{name}.

This package contains HTML documentation for %{name}.


%package -n python3-%{name}
Summary:        Python3 bindings for %{name}
Group:          Development/Python
%{?python_provide:%python_provide python3-%{name}}

%description -n python3-%{name}
This package contains the Python3 binding for %{name}.


%prep
%setup -qn %{dlname}-%{version}
%apply_patches

pathfix.py -pni "%{__python3}" \
configure.py \
src/scripts/build_docs.py \
src/scripts/check.py \
src/scripts/ci_build.py \
src/scripts/cleanup.py \
src/scripts/dist.py \
src/scripts/gen_os_features.py \
src/scripts/install.py \
src/scripts/python_unittests.py \
src/scripts/python_unittests_unix.py \
src/scripts/show_dependencies.py \
src/scripts/test_cli_crypt.py \
src/scripts/test_python.py \
src/scripts/tls_suite_info.py \
src/python/botan2.py

%build
# we have the necessary prerequisites, so enable optional modules
%define enable_modules bzip2,zlib,openssl,sqlite3,lzma

./configure.py \
        --prefix=%{_prefix} \
        --libdir=%{_lib} \
        --docdir=%{_docdir} \
        --cc=gcc \
        --os=linux \
        --cpu=%{_arch} \
        --enable-modules=%{enable_modules} \
        --with-python-version=%{python3_version} \
        --disable-static-library \
        --with-debug-info

%make_build

%install
%make_install \
     INSTALL_CMD_EXEC="install -p -m 755" \
     INSTALL_CMD_DATA="install -p -m 644"

chmod 755 %{buildroot}%{python3_sitearch}/botan2.py

find %{buildroot} -name '*.a' -delete

%check
%ifnarch %{arm}
LD_LIBRARY_PATH=%{buildroot}%{_libdir} ./botan-test
%endif

%files
%{_bindir}/botan
#%{_mandir}/man1/*

%files -n %{libname}
%{_libdir}/libbotan-%{botan_ver}.so.%{major_version}*

%files -n %{devname}
%{_includedir}/botan-%{botan_ver}/
%{_libdir}/libbotan-%{botan_ver}.so
%{_libdir}/pkgconfig/botan-%{botan_ver}.pc

%files doc
%{_docdir}/botan-%{version}/

%files -n python3-%{name}
%{python3_sitearch}/%{name}.py


%changelog
* Thu Mar 31 2022 TerryN <terryn94 at gmail.com> 2.19.1-2pclos2022
- rebuild for python 3.10

* Wed Mar 23 2022 tex - 2.19.1-1pclos2022
- new version
